# passerelle-montpellier-encombrants
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.utils.text import slugify
from django import forms
from django.utils.translation import ugettext_lazy as _

from .models import EncombrantsManagement, Commune, Street

class EncombrantsManagementForm(forms.ModelForm):
    class Meta:
        model = EncombrantsManagement
        exclude = ('slug', 'users')

    def save(self, commit=True):
        if not self.instance.slug:
            self.instance.slug = slugify(self.instance.title)
        return super(EncombrantsManagementForm, self).save(commit=commit)

class EncombrantsManagementUpdateForm(EncombrantsManagementForm):
    class Meta:
        model = EncombrantsManagement
        exclude = ('users',)


class CommuneForm(forms.ModelForm):
    streets = forms.CharField(widget=forms.Textarea(attrs={'cols': 25, 'rows': 10}),
                    help_text=_('one street by line'),
                    required=False)

    class Meta:
        model = Commune

    def save(self):
        obj = super(CommuneForm, self).save()
        if self.cleaned_data['streets']:
            streets = self.cleaned_data['streets'].split('\n')
            for street in streets:
                if street.strip():
                    Street.objects.create(commune=obj, name=street.strip())
        return obj


class StreetsForm(forms.Form):
    streets = forms.CharField(widget=forms.Textarea(attrs={'cols': 25, 'rows': 10}),
                    help_text=_('one street by line'),
                    required=False)
