import requests
import urllib
from datetime import datetime, timedelta

from django.conf import settings
from django.core.management.base import BaseCommand, CommandError

from passerelle.base.signature import sign_url
from passerelle_montpellier_encombrants.utils import email_sectors


class Command(BaseCommand):

    def get(self, url, sign=False):
        api_user = getattr(settings, 'ENCOMBRANTS_API_USER')
        secret = getattr(settings, 'ENCOMBRANTS_API_SECRET')
        orig = getattr(settings, 'ENCOMBRANTS_API_ORIG')
        if sign:
            url = sign_url(url + '&email=' + urllib.quote(api_user), secret) + '&orig='+urllib.quote(orig)
        return requests.get(url, headers={'Accept': 'application/json'})

    def handle(self, *args, **kwargs):
        tomorrow = datetime.today() + timedelta(days=1)
        filter_query = '?filter=pending&filter-date=%s' % tomorrow.strftime('%Y-%m-%d')
        url = getattr(settings, 'ENCOMBRANTS_FORM_URL') + filter_query
        r = self.get(url, True)
        formdefs = []

        if not 'err' in r.json():
            for formdata in r.json():
                if formdata.get('url'):
                    r = self.get(formdata['url'])
                    formdefs.append(r.json())
            email_sectors(formdefs, tomorrow)
        else:
            raise CommandError('Error while retreiving formdefs: %s' % r.json())
