# -*- coding: utf-8 -*-

import csv
from collections import defaultdict
import StringIO

from django.core.mail import EmailMessage
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
from django.template.loader import get_template, Context

from .models import Commune

prefix_map = {
    'ALL': 'ALLEE',
    'AUTO': 'AUTOROUTE',
    'AV': 'AVENUE',
    'BASS': 'BASSIN',
    'BD': 'BOULEVARD',
    'CAR': 'CARREFOUR',
    'CHE': 'CHAUSSEE',
    'COUR': 'COUR',
    'CRS': 'COURS',
    'DESC': 'DESCENTE',
    'DOM': 'DOMAINE',
    'ENCL': 'ENCLOS',
    'ESP': 'ESPLANADE',
    'ESPA': 'ESPACE',
    'GR': '', # "GR GRAND-RUE JEAN MOULIN"
    'IMP': 'IMPASSE',
    'JARD': 'JARDIN',
    'MAIL': '', # "MAIL LE GRAND MAIL"
    'PARC': 'PARC',
    'PARV': '', # "PARV PARVIS DE LA LEGION D HONNEUR"
    'PAS': 'PASSAGE',
    'PL': 'PLACE',
    'PLAN': 'PLAN',
    'PONT': 'PONT',
    'QUA': 'QUAI',
    'R': 'RUE',
    'RAMB': '', # "RAMB RAMBLA DES CALISSONS"
    'RPT': 'ROND-POINT',
    'RTE': 'ROUTE',
    'SQ': 'SQUARE',
    'TSSE': '', # "TSSE TERRASSE DES ALLEES DU BOIS"
    'TUN': 'TUNNEL',
    'VIAD': 'VIADUC',
    'VOI': 'VOIE',
}

def prefix_cleanup(name):
    name = name.strip()
    for prefix, full in prefix_map.items():
        if name.startswith(prefix + ' '):
            name = (full + name[len(prefix):]).strip()
    return name

def get_sector(insee, address=None):
    communes = Commune.objects.filter(insee=insee)
    for commune in communes:
        streets = commune.street_set.all()
        if address and streets:
            for s in streets:
                if prefix_cleanup(s.name) in address.upper():
                    return commune.sector
        else:
            return commune.sector

def email_sectors(formdefs, when):
    subject = get_template('passerelle_montpellier_encombrants/email_subject.txt')
    message = get_template('passerelle_montpellier_encombrants/email_body.txt')

    header = ('Adresse', 'Date', 'Volume',
              'Type d\'encombrant', u'Téléphone', 'Commentaire')

    sectors = defaultdict(list)

    context = Context({'date': when})
    for formdef in formdefs:
        fields = formdef['fields']

        data = [fields.get(d) for d in ('adresse', 'date',
                            'volume', 'type_encombrant',
                            'telephone', 'commentaire')]

        sector = get_sector(fields.get('commune_raw'), fields.get('adresse'))
        if sector:
            sectors[sector.contact_email].append(data)

    for destination, data in sectors.iteritems():
        mail = EmailMessage(subject.render(context), message.render(context),
                            settings.DEFAULT_FROM_EMAIL, [destination])
        attachement_body = StringIO.StringIO()
        attachment = csv.writer(attachement_body)
        attachment.writerow([e.encode("utf-8") for e in header])
        for d in data:
            attachment.writerow([e.encode("utf-8") for e in d])

        mail.attach('demandes.csv', attachement_body.getvalue(), 'text/csv')
        mail.send()
